==> folly_fields-1.0.0.tar.gz: test/util/folly_date_time_extension/next_week_first_day_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:folly_fields/util/folly_date_time_extension.dart';

///
///
///
void main() {
  group(
    'DateTimeExtension nextWeekFirstDay - Monday',
    () {
      Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 20),
        DateTime(2023, 3, 20): DateTime(2023, 3, 27),
        DateTime(2023, 3, 21): DateTime(2023, 3, 27),
        DateTime(2023, 3, 22): DateTime(2023, 3, 27),
        DateTime(2023, 3, 23): DateTime(2023, 3, 27),
        DateTime(2023, 3, 24): DateTime(2023, 3, 27),
        DateTime(2023, 3, 25): DateTime(2023, 3, 27),
        DateTime(2023, 3, 26): DateTime(2023, 3, 27),
        DateTime(2023, 3, 27): DateTime(2023, 4, 3),
        DateTime(2023, 3, 28): DateTime(2023, 4, 3),
        DateTime(2023, 3, 29): DateTime(2023, 4, 3),
        DateTime(2023, 3, 30): DateTime(2023, 4, 3),
        DateTime(2023, 3, 31): DateTime(2023, 4, 3),
        DateTime(2023, 4): DateTime(2023, 4, 3),
        DateTime(2023, 4, 2): DateTime(2023, 4, 3),
        DateTime(2023, 4, 3): DateTime(2023, 4, 10),
        DateTime(2023, 4, 4): DateTime(2023, 4, 10),
        DateTime(2023, 4, 5): DateTime(2023, 4, 10),
        DateTime(2023, 4, 6): DateTime(2023, 4, 10),
        DateTime(2023, 4, 7): DateTime(2023, 4, 10),
        DateTime(2023, 4, 8): DateTime(2023, 4, 10),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () =>
              expect(input.key.nextWeekFirstDay(DateTime.monday), input.value),
        );
      }
    },
  );

  group(
    'DateTimeExtension nextWeekFirstDay - Wednesday',
    () {
      Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 22),
        DateTime(2023, 3, 20): DateTime(2023, 3, 22),
        DateTime(2023, 3, 21): DateTime(2023, 3, 22),
        DateTime(2023, 3, 22): DateTime(2023, 3, 29),
        DateTime(2023, 3, 23): DateTime(2023, 3, 29),
        DateTime(2023, 3, 24): DateTime(2023, 3, 29),
        DateTime(2023, 3, 25): DateTime(2023, 3, 29),
        DateTime(2023, 3, 26): DateTime(2023, 3, 29),
        DateTime(2023, 3, 27): DateTime(2023, 3, 29),
        DateTime(2023, 3, 28): DateTime(2023, 3, 29),
        DateTime(2023, 3, 29): DateTime(2023, 4, 5),
        DateTime(2023, 3, 30): DateTime(2023, 4, 5),
        DateTime(2023, 3, 31): DateTime(2023, 4, 5),
        DateTime(2023, 4): DateTime(2023, 4, 5),
        DateTime(2023, 4, 2): DateTime(2023, 4, 5),
        DateTime(2023, 4, 3): DateTime(2023, 4, 5),
        DateTime(2023, 4, 4): DateTime(2023, 4, 5),
        DateTime(2023, 4, 5): DateTime(2023, 4, 12),
        DateTime(2023, 4, 6): DateTime(2023, 4, 12),
        DateTime(2023, 4, 7): DateTime(2023, 4, 12),
        DateTime(2023, 4, 8): DateTime(2023, 4, 12),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () => expect(
            input.key.nextWeekFirstDay(DateTime.wednesday),
            input.value,
          ),
        );
      }
    },
  );

  group(
    'DateTimeExtension nextWeekFirstDay - Sunday',
    () {
      Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 26),
        DateTime(2023, 3, 20): DateTime(2023, 3, 26),
        DateTime(2023, 3, 21): DateTime(2023, 3, 26),
        DateTime(2023, 3, 22): DateTime(2023, 3, 26),
        DateTime(2023, 3, 23): DateTime(2023, 3, 26),
        DateTime(2023, 3, 24): DateTime(2023, 3, 26),
        DateTime(2023, 3, 25): DateTime(2023, 3, 26),
        DateTime(2023, 3, 26): DateTime(2023, 4, 2),
        DateTime(2023, 3, 27): DateTime(2023, 4, 2),
        DateTime(2023, 3, 28): DateTime(2023, 4, 2),
        DateTime(2023, 3, 29): DateTime(2023, 4, 2),
        DateTime(2023, 3, 30): DateTime(2023, 4, 2),
        DateTime(2023, 3, 31): DateTime(2023, 4, 2),
        DateTime(2023, 4): DateTime(2023, 4, 2),
        DateTime(2023, 4, 2): DateTime(2023, 4, 9),
        DateTime(2023, 4, 3): DateTime(2023, 4, 9),
        DateTime(2023, 4, 4): DateTime(2023, 4, 9),
        DateTime(2023, 4, 5): DateTime(2023, 4, 9),
        DateTime(2023, 4, 6): DateTime(2023, 4, 9),
        DateTime(2023, 4, 7): DateTime(2023, 4, 9),
        DateTime(2023, 4, 8): DateTime(2023, 4, 9),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () => expect(input.key.nextWeekFirstDay(), input.value),
        );
      }
    },
  );
}

==> folly_fields-1.2.1.tar.gz: test/util/folly_date_time_extension/next_week_first_day_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:folly_fields/util/folly_date_time_extension.dart';

///
///
///
void main() {
  group(
    'DateTimeExtension nextWeekFirstDay - Monday',
    () {
      final Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 20),
        DateTime(2023, 3, 20): DateTime(2023, 3, 27),
        DateTime(2023, 3, 21): DateTime(2023, 3, 27),
        DateTime(2023, 3, 22): DateTime(2023, 3, 27),
        DateTime(2023, 3, 23): DateTime(2023, 3, 27),
        DateTime(2023, 3, 24): DateTime(2023, 3, 27),
        DateTime(2023, 3, 25): DateTime(2023, 3, 27),
        DateTime(2023, 3, 26): DateTime(2023, 3, 27),
        DateTime(2023, 3, 27): DateTime(2023, 4, 3),
        DateTime(2023, 3, 28): DateTime(2023, 4, 3),
        DateTime(2023, 3, 29): DateTime(2023, 4, 3),
        DateTime(2023, 3, 30): DateTime(2023, 4, 3),
        DateTime(2023, 3, 31): DateTime(2023, 4, 3),
        DateTime(2023, 4): DateTime(2023, 4, 3),
        DateTime(2023, 4, 2): DateTime(2023, 4, 3),
        DateTime(2023, 4, 3): DateTime(2023, 4, 10),
        DateTime(2023, 4, 4): DateTime(2023, 4, 10),
        DateTime(2023, 4, 5): DateTime(2023, 4, 10),
        DateTime(2023, 4, 6): DateTime(2023, 4, 10),
        DateTime(2023, 4, 7): DateTime(2023, 4, 10),
        DateTime(2023, 4, 8): DateTime(2023, 4, 10),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () =>
              expect(input.key.nextWeekFirstDay(DateTime.monday), input.value),
        );
      }
    },
  );

  group(
    'DateTimeExtension nextWeekFirstDay - Wednesday',
    () {
      final Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 22),
        DateTime(2023, 3, 20): DateTime(2023, 3, 22),
        DateTime(2023, 3, 21): DateTime(2023, 3, 22),
        DateTime(2023, 3, 22): DateTime(2023, 3, 29),
        DateTime(2023, 3, 23): DateTime(2023, 3, 29),
        DateTime(2023, 3, 24): DateTime(2023, 3, 29),
        DateTime(2023, 3, 25): DateTime(2023, 3, 29),
        DateTime(2023, 3, 26): DateTime(2023, 3, 29),
        DateTime(2023, 3, 27): DateTime(2023, 3, 29),
        DateTime(2023, 3, 28): DateTime(2023, 3, 29),
        DateTime(2023, 3, 29): DateTime(2023, 4, 5),
        DateTime(2023, 3, 30): DateTime(2023, 4, 5),
        DateTime(2023, 3, 31): DateTime(2023, 4, 5),
        DateTime(2023, 4): DateTime(2023, 4, 5),
        DateTime(2023, 4, 2): DateTime(2023, 4, 5),
        DateTime(2023, 4, 3): DateTime(2023, 4, 5),
        DateTime(2023, 4, 4): DateTime(2023, 4, 5),
        DateTime(2023, 4, 5): DateTime(2023, 4, 12),
        DateTime(2023, 4, 6): DateTime(2023, 4, 12),
        DateTime(2023, 4, 7): DateTime(2023, 4, 12),
        DateTime(2023, 4, 8): DateTime(2023, 4, 12),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () => expect(
            input.key.nextWeekFirstDay(DateTime.wednesday),
            input.value,
          ),
        );
      }
    },
  );

  group(
    'DateTimeExtension nextWeekFirstDay - Sunday',
    () {
      final Map<DateTime, DateTime> domain = <DateTime, DateTime>{
        DateTime(2023, 3, 19): DateTime(2023, 3, 26),
        DateTime(2023, 3, 20): DateTime(2023, 3, 26),
        DateTime(2023, 3, 21): DateTime(2023, 3, 26),
        DateTime(2023, 3, 22): DateTime(2023, 3, 26),
        DateTime(2023, 3, 23): DateTime(2023, 3, 26),
        DateTime(2023, 3, 24): DateTime(2023, 3, 26),
        DateTime(2023, 3, 25): DateTime(2023, 3, 26),
        DateTime(2023, 3, 26): DateTime(2023, 4, 2),
        DateTime(2023, 3, 27): DateTime(2023, 4, 2),
        DateTime(2023, 3, 28): DateTime(2023, 4, 2),
        DateTime(2023, 3, 29): DateTime(2023, 4, 2),
        DateTime(2023, 3, 30): DateTime(2023, 4, 2),
        DateTime(2023, 3, 31): DateTime(2023, 4, 2),
        DateTime(2023, 4): DateTime(2023, 4, 2),
        DateTime(2023, 4, 2): DateTime(2023, 4, 9),
        DateTime(2023, 4, 3): DateTime(2023, 4, 9),
        DateTime(2023, 4, 4): DateTime(2023, 4, 9),
        DateTime(2023, 4, 5): DateTime(2023, 4, 9),
        DateTime(2023, 4, 6): DateTime(2023, 4, 9),
        DateTime(2023, 4, 7): DateTime(2023, 4, 9),
        DateTime(2023, 4, 8): DateTime(2023, 4, 9),
      };

      for (final MapEntry<DateTime, DateTime> input in domain.entries) {
        test(
          'Testing ${input.key.toIso8601String()}',
          () => expect(input.key.nextWeekFirstDay(), input.value),
        );
      }
    },
  );
}
